@@ -126,6 +126,9 @@
 #define DELAY_SET_ACTION(a1, a2, a3)	((a1 << 0) | (a2 << 1) | (a3 << 2))
 #define DELAY_GET_ACTION(n, action)	((1 << n) & action)
 
+#define FLOAT_TINY		(0.0000001)
+#define FLOAT_CMP(a, b)		(fabs((a) - (b)) < FLOAT_TINY)
+
 typedef struct {
 	double	divisor;			/* delay divisor */
 	uint8_t	mode;				/* User specified mode */
@@ -217,11 +220,15 @@ static const scale_t second_scales[] = {
  */
 static inline unsigned int count_bits(const unsigned int val)
 {
+#if defined(__GNUC__)
+	return __builtin_popcount(val);
+#else
 	register unsigned int c, n = val;
 
 	for (c = 0; n; c++)
 		n &= n - 1;
 	return c;
+#endif
 }
 
 /*
@@ -289,7 +296,7 @@ static inline void stats_init(stats_t *const stats)
  *  get_pagesize()
  *	get pagesize
  */
-size_t get_pagesize(void)
+static size_t get_pagesize(void)
 {
 #ifdef _SC_PAGESIZE
 	long sz;
@@ -527,9 +534,11 @@ static void stats_info(const stats_t *stats)
 		double total = stats->underruns +
 			       stats->overruns + stats->perfect;
 
-		fprintf(stderr, "Overruns:         %6.2f%%\n", total ?
+		fprintf(stderr, "Overruns:         %6.2f%%\n", 
+			FLOAT_CMP(total, 0.0) ?
 			100.0 * (double)stats->underruns / total : 0.0);
-		fprintf(stderr, "Underruns:        %6.2f%%\n", total ?
+		fprintf(stderr, "Underruns:        %6.2f%%\n",
+			FLOAT_CMP(total, 0.0) ?
 			100.0 * (double)stats->overruns / total : 0.0);
 
 		fprintf(stderr, "\nDrift from target rate: (%%)\n");
